export interface DashboardV2Spec {
    id?: number;
    title: string;
    description?: string;
    cursorSync: DashboardCursorSync;
    liveNow?: boolean;
    preload: boolean;
    editable?: boolean;
    links: DashboardLink[];
    tags?: string[];
    timeSettings: TimeSettingsSpec;
    variables: (QueryVariableKind | TextVariableKind | ConstantVariableKind | DatasourceVariableKind | IntervalVariableKind | CustomVariableKind | GroupByVariableKind | AdhocVariableKind)[];
    elements: Record<string, PanelKind>;
    annotations: AnnotationQueryKind[];
    layout: GridLayoutKind;
    schemaVersion: number;
}
export declare const defaultDashboardV2Spec: () => DashboardV2Spec;
export interface AnnotationPanelFilter {
    exclude?: boolean;
    ids: number[];
}
export declare const defaultAnnotationPanelFilter: () => AnnotationPanelFilter;
export declare enum DashboardCursorSync {
    Off = "Off",
    Crosshair = "Crosshair",
    Tooltip = "Tooltip"
}
export declare const defaultDashboardCursorSync: () => DashboardCursorSync;
export interface DashboardLink {
    title: string;
    type: DashboardLinkType;
    icon: string;
    tooltip: string;
    url?: string;
    tags: string[];
    asDropdown: boolean;
    targetBlank: boolean;
    includeVars: boolean;
    keepTime: boolean;
}
export declare const defaultDashboardLink: () => DashboardLink;
export interface DataSourceRef {
    type?: string;
    uid?: string;
}
export declare const defaultDataSourceRef: () => DataSourceRef;
export interface DataTransformerConfig {
    id: string;
    disabled?: boolean;
    filter?: MatcherConfig;
    topic?: "series" | "annotations" | "alertStates";
    options: any;
}
export declare const defaultDataTransformerConfig: () => DataTransformerConfig;
export interface FieldConfigSource {
    defaults: FieldConfig;
    overrides: {
        matcher: MatcherConfig;
        properties: DynamicConfigValue[];
    }[];
}
export declare const defaultFieldConfigSource: () => FieldConfigSource;
export interface FieldConfig {
    displayName?: string;
    displayNameFromDS?: string;
    description?: string;
    path?: string;
    writeable?: boolean;
    filterable?: boolean;
    unit?: string;
    decimals?: number;
    min?: number;
    max?: number;
    mappings?: ValueMapping[];
    thresholds?: ThresholdsConfig;
    color?: FieldColor;
    links?: any[];
    noValue?: string;
    custom?: Record<string, any>;
}
export declare const defaultFieldConfig: () => FieldConfig;
export interface DynamicConfigValue {
    id: string;
    value?: any;
}
export declare const defaultDynamicConfigValue: () => DynamicConfigValue;
export interface MatcherConfig {
    id: string;
    options?: any;
}
export declare const defaultMatcherConfig: () => MatcherConfig;
export interface Threshold {
    value: number | null;
    color: string;
}
export declare const defaultThreshold: () => Threshold;
export declare enum ThresholdsMode {
    Absolute = "absolute",
    Percentage = "percentage"
}
export declare const defaultThresholdsMode: () => ThresholdsMode;
export interface ThresholdsConfig {
    mode: ThresholdsMode;
    steps: Threshold[];
}
export declare const defaultThresholdsConfig: () => ThresholdsConfig;
export type ValueMapping = ValueMap | RangeMap | RegexMap | SpecialValueMap;
export declare const defaultValueMapping: () => ValueMapping;
export declare enum MappingType {
    Value = "value",
    Range = "range",
    Regex = "regex",
    Special = "special"
}
export declare const defaultMappingType: () => MappingType;
export interface ValueMap {
    type: "value";
    options: Record<string, ValueMappingResult>;
}
export declare const defaultValueMap: () => ValueMap;
export interface RangeMap {
    type: "range";
    options: {
        from: number | null;
        to: number | null;
        result: ValueMappingResult;
    };
}
export declare const defaultRangeMap: () => RangeMap;
export interface RegexMap {
    type: "regex";
    options: {
        pattern: string;
        result: ValueMappingResult;
    };
}
export declare const defaultRegexMap: () => RegexMap;
export interface SpecialValueMap {
    type: "special";
    options: {
        match: SpecialValueMatch;
        result: ValueMappingResult;
    };
}
export declare const defaultSpecialValueMap: () => SpecialValueMap;
export declare enum SpecialValueMatch {
    True = "true",
    False = "false",
    Null = "null",
    NotANumber = "nan",
    NullNan = "null+nan",
    Empty = "empty"
}
export declare const defaultSpecialValueMatch: () => SpecialValueMatch;
export interface ValueMappingResult {
    text?: string;
    color?: string;
    icon?: string;
    index?: number;
}
export declare const defaultValueMappingResult: () => ValueMappingResult;
export declare enum FieldColorModeId {
    Thresholds = "thresholds",
    PaletteClassic = "palette-classic",
    PaletteClassicByName = "palette-classic-by-name",
    ContinuousGrYlRd = "continuous-GrYlRd",
    ContinuousRdYlGr = "continuous-RdYlGr",
    ContinuousBlYlRd = "continuous-BlYlRd",
    ContinuousYlRd = "continuous-YlRd",
    ContinuousBlPu = "continuous-BlPu",
    ContinuousYlBl = "continuous-YlBl",
    ContinuousBlues = "continuous-blues",
    ContinuousReds = "continuous-reds",
    ContinuousGreens = "continuous-greens",
    ContinuousPurples = "continuous-purples",
    Fixed = "fixed",
    Shades = "shades"
}
export declare const defaultFieldColorModeId: () => FieldColorModeId;
export declare enum FieldColorSeriesByMode {
    Min = "min",
    Max = "max",
    Last = "last"
}
export declare const defaultFieldColorSeriesByMode: () => FieldColorSeriesByMode;
export interface FieldColor {
    mode: FieldColorModeId;
    fixedColor?: string;
    seriesBy?: FieldColorSeriesByMode;
}
export declare const defaultFieldColor: () => FieldColor;
export declare enum DashboardLinkType {
    Link = "link",
    Dashboards = "dashboards"
}
export declare const defaultDashboardLinkType: () => DashboardLinkType;
export interface Kind {
    kind: string;
    spec: any;
    metadata?: any;
}
export declare const defaultKind: () => Kind;
export interface VizConfigSpec {
    pluginVersion: string;
    options: Record<string, any>;
    fieldConfig: FieldConfigSource;
}
export declare const defaultVizConfigSpec: () => VizConfigSpec;
export interface VizConfigKind {
    kind: string;
    spec: VizConfigSpec;
}
export declare const defaultVizConfigKind: () => VizConfigKind;
export interface AnnotationQuerySpec {
    datasource: DataSourceRef;
    query: DataQueryKind;
    enable: boolean;
    filter: AnnotationPanelFilter;
    hide: boolean;
    iconColor: string;
    name: string;
}
export declare const defaultAnnotationQuerySpec: () => AnnotationQuerySpec;
export interface AnnotationQueryKind {
    kind: "AnnotationQuery";
    spec: AnnotationQuerySpec;
}
export declare const defaultAnnotationQueryKind: () => AnnotationQueryKind;
export interface QueryOptionsSpec {
    timeFrom?: string;
    maxDataPoints?: number;
    timeShift?: string;
    queryCachingTTL?: number;
    interval?: string;
    cacheTimeout?: string;
}
export declare const defaultQueryOptionsSpec: () => QueryOptionsSpec;
export interface DataQueryKind {
    kind: string;
    spec: Record<string, any>;
}
export declare const defaultDataQueryKind: () => DataQueryKind;
export interface PanelQuerySpec {
    query: DataQueryKind;
    datasource: DataSourceRef;
    refId: string;
    hidden: boolean;
}
export declare const defaultPanelQuerySpec: () => PanelQuerySpec;
export interface PanelQueryKind {
    kind: "PanelQuery";
    spec: PanelQuerySpec;
}
export declare const defaultPanelQueryKind: () => PanelQueryKind;
export interface TransformationKind {
    kind: string;
    spec: DataTransformerConfig;
}
export declare const defaultTransformationKind: () => TransformationKind;
export interface QueryGroupSpec {
    queries: PanelQueryKind[];
    transformations: TransformationKind[];
    queryOptions: QueryOptionsSpec;
}
export declare const defaultQueryGroupSpec: () => QueryGroupSpec;
export interface QueryGroupKind {
    kind: "QueryGroup";
    spec: QueryGroupSpec;
}
export declare const defaultQueryGroupKind: () => QueryGroupKind;
export interface TimeSettingsSpec {
    timezone?: string;
    from: string;
    to: string;
    autoRefresh: string;
    autoRefreshIntervals: string[];
    quickRanges: string[];
    hideTimepicker: boolean;
    weekStart: string;
    fiscalYearStartMonth: number;
    nowDelay?: string;
}
export declare const defaultTimeSettingsSpec: () => TimeSettingsSpec;
export interface GridLayoutItemSpec {
    x: number;
    y: number;
    width: number;
    height: number;
    element: ElementReference;
}
export declare const defaultGridLayoutItemSpec: () => GridLayoutItemSpec;
export interface GridLayoutItemKind {
    kind: "GridLayoutItem";
    spec: GridLayoutItemSpec;
}
export declare const defaultGridLayoutItemKind: () => GridLayoutItemKind;
export interface GridLayoutSpec {
    items: GridLayoutItemKind[];
}
export declare const defaultGridLayoutSpec: () => GridLayoutSpec;
export interface GridLayoutKind {
    kind: "GridLayout";
    spec: GridLayoutSpec;
}
export declare const defaultGridLayoutKind: () => GridLayoutKind;
export interface PanelSpec {
    uid: string;
    title: string;
    description: string;
    links: DashboardLink[];
    data: QueryGroupKind;
    vizConfig: VizConfigKind;
}
export declare const defaultPanelSpec: () => PanelSpec;
export interface PanelKind {
    kind: "Panel";
    spec: PanelSpec;
}
export declare const defaultPanelKind: () => PanelKind;
export interface ElementReference {
    kind: "ElementReference";
    name: string;
}
export declare const defaultElementReference: () => ElementReference;
export type VariableValue = VariableValueSingle | VariableValueSingle[];
export declare const defaultVariableValue: () => VariableValue;
export type VariableValueSingle = string | boolean | number | CustomVariableValue;
export declare const defaultVariableValueSingle: () => VariableValueSingle;
export interface CustomFormatterVariable {
    name: string;
    type: VariableType;
    multi: boolean;
    includeAll: boolean;
}
export declare const defaultCustomFormatterVariable: () => CustomFormatterVariable;
export interface CustomVariableValue {
    formatter: string | VariableCustomFormatterFn;
}
export declare const defaultCustomVariableValue: () => CustomVariableValue;
export interface VariableCustomFormatterFn {
    value: any;
    legacyVariableModel: {
        name: string;
        type: VariableType;
        multi: boolean;
        includeAll: boolean;
    };
    legacyDefaultFormatter?: VariableCustomFormatterFn;
}
export declare const defaultVariableCustomFormatterFn: () => VariableCustomFormatterFn;
export declare enum VariableType {
    Query = "query",
    Adhoc = "adhoc",
    Groupby = "groupby",
    Constant = "constant",
    Datasource = "datasource",
    Interval = "interval",
    Textbox = "textbox",
    Custom = "custom",
    System = "system",
    Snapshot = "snapshot"
}
export declare const defaultVariableType: () => VariableType;
export declare enum VariableSort {
    Disabled = "disabled",
    AlphabeticalAsc = "alphabeticalAsc",
    AlphabeticalDesc = "alphabeticalDesc",
    NumericalAsc = "numericalAsc",
    NumericalDesc = "numericalDesc",
    AlphabeticalCaseInsensitiveAsc = "alphabeticalCaseInsensitiveAsc",
    AlphabeticalCaseInsensitiveDesc = "alphabeticalCaseInsensitiveDesc",
    NaturalAsc = "naturalAsc",
    NaturalDesc = "naturalDesc"
}
export declare const defaultVariableSort: () => VariableSort;
export declare enum VariableRefresh {
    Never = "never",
    OnDashboardLoad = "onDashboardLoad",
    OnTimeRangeChanged = "onTimeRangeChanged"
}
export declare const defaultVariableRefresh: () => VariableRefresh;
export declare enum VariableHide {
    DontHide = "dontHide",
    HideLabel = "hideLabel",
    HideVariable = "hideVariable"
}
export declare const defaultVariableHide: () => VariableHide;
export interface VariableValueOption {
    label: string;
    value: VariableValueSingle;
    group?: string;
}
export declare const defaultVariableValueOption: () => VariableValueOption;
export interface VariableOption {
    selected?: boolean;
    text: string | string[];
    value: string | string[];
}
export declare const defaultVariableOption: () => VariableOption;
export interface QueryVariableSpec {
    name: string;
    current: VariableOption;
    label?: string;
    hide: VariableHide;
    refresh: VariableRefresh;
    skipUrlSync: boolean;
    description?: string;
    datasource: DataSourceRef;
    query: string | DataQueryKind;
    regex: string;
    sort: VariableSort;
    definition?: string;
    options: VariableOption[];
    multi: boolean;
    includeAll: boolean;
    allValue?: string;
    placeholder?: string;
}
export declare const defaultQueryVariableSpec: () => QueryVariableSpec;
export interface QueryVariableKind {
    kind: "QueryVariable";
    spec: QueryVariableSpec;
}
export declare const defaultQueryVariableKind: () => QueryVariableKind;
export interface TextVariableSpec {
    name: string;
    current: VariableOption;
    query: string;
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultTextVariableSpec: () => TextVariableSpec;
export interface TextVariableKind {
    kind: "TextVariable";
    spec: TextVariableSpec;
}
export declare const defaultTextVariableKind: () => TextVariableKind;
export interface ConstantVariableSpec {
    name: string;
    query: string;
    current: VariableOption;
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultConstantVariableSpec: () => ConstantVariableSpec;
export interface ConstantVariableKind {
    kind: "ConstantVariable";
    spec: ConstantVariableSpec;
}
export declare const defaultConstantVariableKind: () => ConstantVariableKind;
export interface DatasourceVariableSpec {
    name: string;
    pluginId: string;
    refresh: VariableRefresh;
    regex: string;
    current: VariableOption;
    defaultOptionEnabled: boolean;
    options: VariableOption[];
    multi: boolean;
    includeAll: boolean;
    allValue?: string;
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultDatasourceVariableSpec: () => DatasourceVariableSpec;
export interface DatasourceVariableKind {
    kind: "DatasourceVariable";
    spec: DatasourceVariableSpec;
}
export declare const defaultDatasourceVariableKind: () => DatasourceVariableKind;
export interface IntervalVariableSpec {
    name: string;
    query: string;
    current: VariableOption;
    options: VariableOption[];
    auto: boolean;
    auto_min: string;
    auto_count: number;
    refresh: VariableRefresh;
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultIntervalVariableSpec: () => IntervalVariableSpec;
export interface IntervalVariableKind {
    kind: "IntervalVariable";
    spec: IntervalVariableSpec;
}
export declare const defaultIntervalVariableKind: () => IntervalVariableKind;
export interface CustomVariableSpec {
    name: string;
    query: string;
    current: VariableOption;
    options: VariableOption[];
    multi: boolean;
    includeAll: boolean;
    allValue?: string;
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultCustomVariableSpec: () => CustomVariableSpec;
export interface CustomVariableKind {
    kind: "CustomVariable";
    spec: CustomVariableSpec;
}
export declare const defaultCustomVariableKind: () => CustomVariableKind;
export interface GroupByVariableSpec {
    name: string;
    datasource: DataSourceRef;
    current: VariableOption;
    options: VariableOption[];
    multi: boolean;
    includeAll: boolean;
    allValue?: string;
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultGroupByVariableSpec: () => GroupByVariableSpec;
export interface GroupByVariableKind {
    kind: "GroupByVariable";
    spec: GroupByVariableSpec;
}
export declare const defaultGroupByVariableKind: () => GroupByVariableKind;
export interface AdhocVariableSpec {
    name: string;
    datasource: DataSourceRef;
    baseFilters: AdHocFilterWithLabels[];
    filters: AdHocFilterWithLabels[];
    defaultKeys: MetricFindValue[];
    label?: string;
    hide: VariableHide;
    skipUrlSync: boolean;
    description?: string;
}
export declare const defaultAdhocVariableSpec: () => AdhocVariableSpec;
export interface MetricFindValue {
    text: string;
    value?: string | number;
    group?: string;
    expandable?: boolean;
}
export declare const defaultMetricFindValue: () => MetricFindValue;
export interface AdHocFilterWithLabels {
    key: string;
    operator: string;
    value: string;
    values?: string[];
    keyLabel?: string;
    valueLabels?: string[];
    forceEdit?: boolean;
    condition?: string;
}
export declare const defaultAdHocFilterWithLabels: () => AdHocFilterWithLabels;
export interface AdhocVariableKind {
    kind: "AdhocVariable";
    spec: AdhocVariableSpec;
}
export declare const defaultAdhocVariableKind: () => AdhocVariableKind;
