import { createContext, useContext } from 'react';
import { useObservable } from 'react-use';
import { locationService } from './LocationService.js';
import { sidecarServiceSingleton_EXPERIMENTAL } from './SidecarService_EXPERIMENTAL.js';

const SidecarContext_EXPERIMENTAL = createContext(
  sidecarServiceSingleton_EXPERIMENTAL
);
const HIDDEN_ROUTES = ["/login"];
function useSidecar_EXPERIMENTAL() {
  const service = useContext(SidecarContext_EXPERIMENTAL);
  if (!service) {
    throw new Error("No SidecarContext found");
  }
  const initialContext = useObservable(service.initialContextObservable, service.initialContext);
  const activePluginId = useObservable(service.activePluginIdObservable, service.activePluginId);
  const locationService$1 = service.getLocationService();
  const forceHidden = HIDDEN_ROUTES.includes(locationService.getLocation().pathname);
  return {
    activePluginId: forceHidden ? void 0 : activePluginId,
    initialContext: forceHidden ? void 0 : initialContext,
    locationService: locationService$1,
    // TODO: currently this allows anybody to open any app, in the future we should probably scope this to the
    //  current app but that means we will need to incorporate this better into the plugin platform APIs which
    //  we will do once the functionality is reasonably stable
    openApp: (pluginId, context) => {
      if (forceHidden) {
        return;
      }
      return service.openApp(pluginId, context);
    },
    openAppV2: (pluginId, path) => {
      if (forceHidden) {
        return;
      }
      return service.openAppV2(pluginId, path);
    },
    closeApp: () => service.closeApp(),
    isAppOpened: (pluginId) => {
      if (forceHidden) {
        return false;
      }
      return service.isAppOpened(pluginId);
    }
  };
}

export { SidecarContext_EXPERIMENTAL, useSidecar_EXPERIMENTAL };
//# sourceMappingURL=SidecarContext_EXPERIMENTAL.js.map
