import { Registry } from '../utils/Registry.js';
import { createColors } from './createColors.js';
import { createTheme } from './createTheme.js';

function getThemeById(id) {
  var _a;
  const theme = (_a = themeRegistry.getIfExists(id)) != null ? _a : themeRegistry.get("dark");
  return theme.build();
}
function getBuiltInThemes(includeExtras) {
  return themeRegistry.list().filter((item) => {
    return includeExtras ? true : !item.isExtra;
  });
}
const themeRegistry = new Registry(() => {
  return [
    { id: "system", name: "System preference", build: getSystemPreferenceTheme },
    { id: "dark", name: "Dark", build: () => createTheme({ colors: { mode: "dark" } }) },
    { id: "light", name: "Light", build: () => createTheme({ colors: { mode: "light" } }) },
    { id: "debug", name: "Debug", build: createDebug, isExtra: true }
  ];
});
function getSystemPreferenceTheme() {
  const mediaResult = window.matchMedia("(prefers-color-scheme: dark)");
  const id = mediaResult.matches ? "dark" : "light";
  return getThemeById(id);
}
function createDebug() {
  const baseDarkColors = createColors({
    mode: "dark"
  });
  return createTheme({
    name: "Debug",
    colors: {
      mode: "dark",
      background: {
        canvas: "#000033",
        primary: "#000044",
        secondary: "#000055"
      },
      text: {
        primary: "#bbbb00",
        secondary: "#888800",
        disabled: "#444400",
        link: "#dddd00",
        maxContrast: "#ffff00"
      },
      border: {
        weak: "#ff000044",
        medium: "#ff000088",
        strong: "#ff0000ff"
      },
      primary: {
        ...baseDarkColors.primary,
        border: "#ff000088",
        text: "#cccc00",
        contrastText: "#ffff00",
        shade: "#9900dd"
      },
      secondary: {
        ...baseDarkColors.secondary,
        border: "#ff000088",
        text: "#cccc00",
        contrastText: "#ffff00",
        shade: "#9900dd"
      },
      info: {
        ...baseDarkColors.info,
        shade: "#9900dd"
      },
      warning: {
        ...baseDarkColors.warning,
        shade: "#9900dd"
      },
      success: {
        ...baseDarkColors.success,
        shade: "#9900dd"
      },
      error: {
        ...baseDarkColors.error,
        shade: "#9900dd"
      },
      action: {
        hover: "#9900dd",
        focus: "#6600aa",
        selected: "#440088"
      }
    },
    shape: {
      borderRadius: 8
    }
  });
}

export { getBuiltInThemes, getThemeById };
//# sourceMappingURL=registry.js.map
