import { stringStartsAsRegEx, stringToJsRegex } from '../../text/string.js';
import { FrameMatcherID } from './ids.js';

const refIdMatcher = {
  id: FrameMatcherID.byRefId,
  name: "Query refId",
  description: "match the refId",
  defaultOptions: "A",
  get: (pattern) => {
    let regex = null;
    if (stringStartsAsRegEx(pattern)) {
      try {
        regex = stringToJsRegex(pattern);
      } catch (error) {
        if (error instanceof Error) {
          console.warn(error.message);
        }
      }
    }
    return (frame) => {
      var _a;
      return (_a = regex == null ? void 0 : regex.test(frame.refId || "")) != null ? _a : frame.refId === pattern;
    };
  },
  getOptionsDisplayText: (pattern) => {
    return `RefID: ${pattern}`;
  }
};
function getRefIdMatchers() {
  return [refIdMatcher];
}

export { getRefIdMatchers };
//# sourceMappingURL=refIdMatcher.js.map
